components

package
v1.0.0-beta.9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 23, 2025 License: GPL-3.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DraftBanner

func DraftBanner() templ.Component

DraftBanner renders a warning banner indicating draft content.

func Note

func Note(note site.Note) templ.Component

Note renders a single note.

func NoteList

func NoteList(notes site.Notes) templ.Component

NoteList renders a list of notes.

func PartTitle

func PartTitle(post *site.Post) templ.Component

PartTitle renders a part-prefixed title for use in series contexts. Format: "Part X: Post Title"

func Post

func Post(post *site.Post, seriesInfo *site.SeriesPostInfo) templ.Component

Post renders a single post with optional series navigation.

func PostList

func PostList(posts site.Posts) templ.Component

PostList renders a list of posts.

func SeriesNav

func SeriesNav(info site.SeriesPostInfo) templ.Component

SeriesNav renders navigation for a post that belongs to a series.

func SeriesPostTitle

func SeriesPostTitle(post *site.Post) templ.Component

SeriesPostTitle renders a fully-formatted series post title. Format: "Series Name: Part X - Post Title"

Types

This section is empty.

Directories

Path Synopsis
Package icons contains components that render SVG icons.
Package icons contains components that render SVG icons.

Jump to